import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { ConnectCasesClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectCasesClient";
import { GetLayoutRequest, GetLayoutResponse } from "../models/models_0";
/**
 * @public
 */
export { __MetadataBearer, $Command };
/**
 * @public
 *
 * The input for {@link GetLayoutCommand}.
 */
export interface GetLayoutCommandInput extends GetLayoutRequest {
}
/**
 * @public
 *
 * The output of {@link GetLayoutCommand}.
 */
export interface GetLayoutCommandOutput extends GetLayoutResponse, __MetadataBearer {
}
/**
 * @public
 * <p>Returns the details for the requested layout.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectCasesClient, GetLayoutCommand } from "@aws-sdk/client-connectcases"; // ES Modules import
 * // const { ConnectCasesClient, GetLayoutCommand } = require("@aws-sdk/client-connectcases"); // CommonJS import
 * const client = new ConnectCasesClient(config);
 * const input = { // GetLayoutRequest
 *   domainId: "STRING_VALUE", // required
 *   layoutId: "STRING_VALUE", // required
 * };
 * const command = new GetLayoutCommand(input);
 * const response = await client.send(command);
 * // { // GetLayoutResponse
 * //   layoutId: "STRING_VALUE", // required
 * //   layoutArn: "STRING_VALUE", // required
 * //   name: "STRING_VALUE", // required
 * //   content: { // LayoutContent Union: only one key present
 * //     basic: { // BasicLayout
 * //       topPanel: { // LayoutSections
 * //         sections: [ // SectionsList
 * //           { // Section Union: only one key present
 * //             fieldGroup: { // FieldGroup
 * //               name: "STRING_VALUE",
 * //               fields: [ // FieldList // required
 * //                 { // FieldItem
 * //                   id: "STRING_VALUE", // required
 * //                 },
 * //               ],
 * //             },
 * //           },
 * //         ],
 * //       },
 * //       moreInfo: {
 * //         sections: [
 * //           {//  Union: only one key present
 * //             fieldGroup: {
 * //               name: "STRING_VALUE",
 * //               fields: [ // required
 * //                 {
 * //                   id: "STRING_VALUE", // required
 * //                 },
 * //               ],
 * //             },
 * //           },
 * //         ],
 * //       },
 * //     },
 * //   },
 * //   tags: { // Tags
 * //     "<keys>": "STRING_VALUE",
 * //   },
 * // };
 *
 * ```
 *
 * @param GetLayoutCommandInput - {@link GetLayoutCommandInput}
 * @returns {@link GetLayoutCommandOutput}
 * @see {@link GetLayoutCommandInput} for command's `input` shape.
 * @see {@link GetLayoutCommandOutput} for command's `response` shape.
 * @see {@link ConnectCasesClientResolvedConfig | config} for ConnectCasesClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>You do not have sufficient access to perform this action.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>We couldn't process your request because of an issue with the server. Try again
 *       later.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>We couldn't find the requested resource. Check that your resources exists and were created
 *       in the same Amazon Web Services Region as your request, and try your request again.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The rate has been exceeded for this API. Please try again after a few minutes.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>The request isn't valid. Check the syntax and try again.</p>
 *
 * @throws {@link ConnectCasesServiceException}
 * <p>Base exception class for all service exceptions from ConnectCases service.</p>
 *
 */
export declare class GetLayoutCommand extends $Command<GetLayoutCommandInput, GetLayoutCommandOutput, ConnectCasesClientResolvedConfig> {
    readonly input: GetLayoutCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    /**
     * @public
     */
    constructor(input: GetLayoutCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: ConnectCasesClientResolvedConfig, options?: __HttpHandlerOptions): Handler<GetLayoutCommandInput, GetLayoutCommandOutput>;
    /**
     * @internal
     */
    private serialize;
    /**
     * @internal
     */
    private deserialize;
}
