import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { ConnectCasesClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectCasesClient";
import { PutCaseEventConfigurationRequest, PutCaseEventConfigurationResponse } from "../models/models_0";
/**
 * @public
 */
export { __MetadataBearer, $Command };
/**
 * @public
 *
 * The input for {@link PutCaseEventConfigurationCommand}.
 */
export interface PutCaseEventConfigurationCommandInput extends PutCaseEventConfigurationRequest {
}
/**
 * @public
 *
 * The output of {@link PutCaseEventConfigurationCommand}.
 */
export interface PutCaseEventConfigurationCommandOutput extends PutCaseEventConfigurationResponse, __MetadataBearer {
}
/**
 * @public
 * <p>API for adding case event publishing configuration</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectCasesClient, PutCaseEventConfigurationCommand } from "@aws-sdk/client-connectcases"; // ES Modules import
 * // const { ConnectCasesClient, PutCaseEventConfigurationCommand } = require("@aws-sdk/client-connectcases"); // CommonJS import
 * const client = new ConnectCasesClient(config);
 * const input = { // PutCaseEventConfigurationRequest
 *   domainId: "STRING_VALUE", // required
 *   eventBridge: { // EventBridgeConfiguration
 *     enabled: true || false, // required
 *     includedData: { // EventIncludedData
 *       caseData: { // CaseEventIncludedData
 *         fields: [ // FieldIdentifierList // required
 *           { // FieldIdentifier
 *             id: "STRING_VALUE", // required
 *           },
 *         ],
 *       },
 *       relatedItemData: { // RelatedItemEventIncludedData
 *         includeContent: true || false, // required
 *       },
 *     },
 *   },
 * };
 * const command = new PutCaseEventConfigurationCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param PutCaseEventConfigurationCommandInput - {@link PutCaseEventConfigurationCommandInput}
 * @returns {@link PutCaseEventConfigurationCommandOutput}
 * @see {@link PutCaseEventConfigurationCommandInput} for command's `input` shape.
 * @see {@link PutCaseEventConfigurationCommandOutput} for command's `response` shape.
 * @see {@link ConnectCasesClientResolvedConfig | config} for ConnectCasesClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>You do not have sufficient access to perform this action.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>We couldn't process your request because of an issue with the server. Try again
 *       later.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>We couldn't find the requested resource. Check that your resources exists and were created
 *       in the same Amazon Web Services Region as your request, and try your request again.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The rate has been exceeded for this API. Please try again after a few minutes.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>The request isn't valid. Check the syntax and try again.</p>
 *
 * @throws {@link ConnectCasesServiceException}
 * <p>Base exception class for all service exceptions from ConnectCases service.</p>
 *
 */
export declare class PutCaseEventConfigurationCommand extends $Command<PutCaseEventConfigurationCommandInput, PutCaseEventConfigurationCommandOutput, ConnectCasesClientResolvedConfig> {
    readonly input: PutCaseEventConfigurationCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    /**
     * @public
     */
    constructor(input: PutCaseEventConfigurationCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: ConnectCasesClientResolvedConfig, options?: __HttpHandlerOptions): Handler<PutCaseEventConfigurationCommandInput, PutCaseEventConfigurationCommandOutput>;
    /**
     * @internal
     */
    private serialize;
    /**
     * @internal
     */
    private deserialize;
}
