import { ExceptionOptionType as __ExceptionOptionType } from "@aws-sdk/smithy-client";
import { ConnectCasesServiceException as __BaseException } from "./ConnectCasesServiceException";
export declare class AccessDeniedException extends __BaseException {
  readonly name: "AccessDeniedException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<AccessDeniedException, __BaseException>
  );
}
export declare class ConflictException extends __BaseException {
  readonly name: "ConflictException";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}
export type FieldValueUnion =
  | FieldValueUnion.BooleanValueMember
  | FieldValueUnion.DoubleValueMember
  | FieldValueUnion.StringValueMember
  | FieldValueUnion.$UnknownMember;
export declare namespace FieldValueUnion {
  interface StringValueMember {
    stringValue: string;
    doubleValue?: never;
    booleanValue?: never;
    $unknown?: never;
  }
  interface DoubleValueMember {
    stringValue?: never;
    doubleValue: number;
    booleanValue?: never;
    $unknown?: never;
  }
  interface BooleanValueMember {
    stringValue?: never;
    doubleValue?: never;
    booleanValue: boolean;
    $unknown?: never;
  }
  interface $UnknownMember {
    stringValue?: never;
    doubleValue?: never;
    booleanValue?: never;
    $unknown: [string, any];
  }
  interface Visitor<T> {
    stringValue: (value: string) => T;
    doubleValue: (value: number) => T;
    booleanValue: (value: boolean) => T;
    _: (name: string, value: any) => T;
  }
  const visit: <T>(value: FieldValueUnion, visitor: Visitor<T>) => T;
}
export interface FieldValue {
  id: string | undefined;
  value: FieldValueUnion | undefined;
}
export interface CreateCaseRequest {
  domainId: string | undefined;
  templateId: string | undefined;
  fields: FieldValue[] | undefined;
  clientToken?: string;
}
export interface CreateCaseResponse {
  caseId: string | undefined;
  caseArn: string | undefined;
}
export declare class InternalServerException extends __BaseException {
  readonly name: "InternalServerException";
  readonly $fault: "server";
  $retryable: {};
  retryAfterSeconds?: number;
  constructor(
    opts: __ExceptionOptionType<InternalServerException, __BaseException>
  );
}
export declare class ResourceNotFoundException extends __BaseException {
  readonly name: "ResourceNotFoundException";
  readonly $fault: "client";
  resourceId: string | undefined;
  resourceType: string | undefined;
  constructor(
    opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>
  );
}
export declare class ThrottlingException extends __BaseException {
  readonly name: "ThrottlingException";
  readonly $fault: "client";
  $retryable: {};
  constructor(
    opts: __ExceptionOptionType<ThrottlingException, __BaseException>
  );
}
export declare class ValidationException extends __BaseException {
  readonly name: "ValidationException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ValidationException, __BaseException>
  );
}
export interface FieldIdentifier {
  id: string | undefined;
}
export interface GetCaseRequest {
  caseId: string | undefined;
  domainId: string | undefined;
  fields: FieldIdentifier[] | undefined;
  nextToken?: string;
}
export interface GetCaseResponse {
  fields: FieldValue[] | undefined;
  templateId: string | undefined;
  nextToken?: string;
  tags?: Record<string, string>;
}
export interface ListCasesForContactRequest {
  domainId: string | undefined;
  contactArn: string | undefined;
  maxResults?: number;
  nextToken?: string;
}
export interface CaseSummary {
  caseId: string | undefined;
  templateId: string | undefined;
}
export interface ListCasesForContactResponse {
  cases: CaseSummary[] | undefined;
  nextToken?: string;
}
export declare const CommentBodyTextType: {
  readonly PLAINTEXT: "Text/Plain";
};
export type CommentBodyTextType =
  (typeof CommentBodyTextType)[keyof typeof CommentBodyTextType];
export interface CommentContent {
  body: string | undefined;
  contentType: CommentBodyTextType | string | undefined;
}
export interface Contact {
  contactArn: string | undefined;
}
export type RelatedItemInputContent =
  | RelatedItemInputContent.CommentMember
  | RelatedItemInputContent.ContactMember
  | RelatedItemInputContent.$UnknownMember;
export declare namespace RelatedItemInputContent {
  interface ContactMember {
    contact: Contact;
    comment?: never;
    $unknown?: never;
  }
  interface CommentMember {
    contact?: never;
    comment: CommentContent;
    $unknown?: never;
  }
  interface $UnknownMember {
    contact?: never;
    comment?: never;
    $unknown: [string, any];
  }
  interface Visitor<T> {
    contact: (value: Contact) => T;
    comment: (value: CommentContent) => T;
    _: (name: string, value: any) => T;
  }
  const visit: <T>(value: RelatedItemInputContent, visitor: Visitor<T>) => T;
}
export declare const RelatedItemType: {
  readonly COMMENT: "Comment";
  readonly CONTACT: "Contact";
};
export type RelatedItemType =
  (typeof RelatedItemType)[keyof typeof RelatedItemType];
export interface CreateRelatedItemRequest {
  domainId: string | undefined;
  caseId: string | undefined;
  type: RelatedItemType | string | undefined;
  content: RelatedItemInputContent | undefined;
}
export interface CreateRelatedItemResponse {
  relatedItemId: string | undefined;
  relatedItemArn: string | undefined;
}
export declare class ServiceQuotaExceededException extends __BaseException {
  readonly name: "ServiceQuotaExceededException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ServiceQuotaExceededException, __BaseException>
  );
}
export interface CommentFilter {}
export interface ContactFilter {
  channel?: string[];
  contactArn?: string;
}
export type RelatedItemTypeFilter =
  | RelatedItemTypeFilter.CommentMember
  | RelatedItemTypeFilter.ContactMember
  | RelatedItemTypeFilter.$UnknownMember;
export declare namespace RelatedItemTypeFilter {
  interface ContactMember {
    contact: ContactFilter;
    comment?: never;
    $unknown?: never;
  }
  interface CommentMember {
    contact?: never;
    comment: CommentFilter;
    $unknown?: never;
  }
  interface $UnknownMember {
    contact?: never;
    comment?: never;
    $unknown: [string, any];
  }
  interface Visitor<T> {
    contact: (value: ContactFilter) => T;
    comment: (value: CommentFilter) => T;
    _: (name: string, value: any) => T;
  }
  const visit: <T>(value: RelatedItemTypeFilter, visitor: Visitor<T>) => T;
}
export interface SearchRelatedItemsRequest {
  domainId: string | undefined;
  caseId: string | undefined;
  maxResults?: number;
  nextToken?: string;
  filters?: RelatedItemTypeFilter[];
}
export interface ContactContent {
  contactArn: string | undefined;
  channel: string | undefined;
  connectedToSystemTime: Date | undefined;
}
export type RelatedItemContent =
  | RelatedItemContent.CommentMember
  | RelatedItemContent.ContactMember
  | RelatedItemContent.$UnknownMember;
export declare namespace RelatedItemContent {
  interface ContactMember {
    contact: ContactContent;
    comment?: never;
    $unknown?: never;
  }
  interface CommentMember {
    contact?: never;
    comment: CommentContent;
    $unknown?: never;
  }
  interface $UnknownMember {
    contact?: never;
    comment?: never;
    $unknown: [string, any];
  }
  interface Visitor<T> {
    contact: (value: ContactContent) => T;
    comment: (value: CommentContent) => T;
    _: (name: string, value: any) => T;
  }
  const visit: <T>(value: RelatedItemContent, visitor: Visitor<T>) => T;
}
export interface SearchRelatedItemsResponseItem {
  relatedItemId: string | undefined;
  type: RelatedItemType | string | undefined;
  associationTime: Date | undefined;
  content: RelatedItemContent | undefined;
  tags?: Record<string, string>;
}
export interface SearchRelatedItemsResponse {
  nextToken?: string;
  relatedItems: SearchRelatedItemsResponseItem[] | undefined;
}
export type FieldFilter =
  | FieldFilter.ContainsMember
  | FieldFilter.EqualToMember
  | FieldFilter.GreaterThanMember
  | FieldFilter.GreaterThanOrEqualToMember
  | FieldFilter.LessThanMember
  | FieldFilter.LessThanOrEqualToMember
  | FieldFilter.$UnknownMember;
export declare namespace FieldFilter {
  interface EqualToMember {
    equalTo: FieldValue;
    contains?: never;
    greaterThan?: never;
    greaterThanOrEqualTo?: never;
    lessThan?: never;
    lessThanOrEqualTo?: never;
    $unknown?: never;
  }
  interface ContainsMember {
    equalTo?: never;
    contains: FieldValue;
    greaterThan?: never;
    greaterThanOrEqualTo?: never;
    lessThan?: never;
    lessThanOrEqualTo?: never;
    $unknown?: never;
  }
  interface GreaterThanMember {
    equalTo?: never;
    contains?: never;
    greaterThan: FieldValue;
    greaterThanOrEqualTo?: never;
    lessThan?: never;
    lessThanOrEqualTo?: never;
    $unknown?: never;
  }
  interface GreaterThanOrEqualToMember {
    equalTo?: never;
    contains?: never;
    greaterThan?: never;
    greaterThanOrEqualTo: FieldValue;
    lessThan?: never;
    lessThanOrEqualTo?: never;
    $unknown?: never;
  }
  interface LessThanMember {
    equalTo?: never;
    contains?: never;
    greaterThan?: never;
    greaterThanOrEqualTo?: never;
    lessThan: FieldValue;
    lessThanOrEqualTo?: never;
    $unknown?: never;
  }
  interface LessThanOrEqualToMember {
    equalTo?: never;
    contains?: never;
    greaterThan?: never;
    greaterThanOrEqualTo?: never;
    lessThan?: never;
    lessThanOrEqualTo: FieldValue;
    $unknown?: never;
  }
  interface $UnknownMember {
    equalTo?: never;
    contains?: never;
    greaterThan?: never;
    greaterThanOrEqualTo?: never;
    lessThan?: never;
    lessThanOrEqualTo?: never;
    $unknown: [string, any];
  }
  interface Visitor<T> {
    equalTo: (value: FieldValue) => T;
    contains: (value: FieldValue) => T;
    greaterThan: (value: FieldValue) => T;
    greaterThanOrEqualTo: (value: FieldValue) => T;
    lessThan: (value: FieldValue) => T;
    lessThanOrEqualTo: (value: FieldValue) => T;
    _: (name: string, value: any) => T;
  }
  const visit: <T>(value: FieldFilter, visitor: Visitor<T>) => T;
}
export declare const Order: {
  readonly ASCENDING: "Asc";
  readonly DESCENDING: "Desc";
};
export type Order = (typeof Order)[keyof typeof Order];
export interface Sort {
  fieldId: string | undefined;
  sortOrder: Order | string | undefined;
}
export interface SearchCasesResponseItem {
  caseId: string | undefined;
  templateId: string | undefined;
  fields: FieldValue[] | undefined;
  tags?: Record<string, string>;
}
export interface SearchCasesResponse {
  nextToken?: string;
  cases: SearchCasesResponseItem[] | undefined;
}
export interface UpdateCaseRequest {
  domainId: string | undefined;
  caseId: string | undefined;
  fields: FieldValue[] | undefined;
}
export interface UpdateCaseResponse {}
export interface CreateDomainRequest {
  name: string | undefined;
}
export declare const DomainStatus: {
  readonly ACTIVE: "Active";
  readonly CREATION_FAILED: "CreationFailed";
  readonly CREATION_IN_PROGRESS: "CreationInProgress";
};
export type DomainStatus = (typeof DomainStatus)[keyof typeof DomainStatus];
export interface CreateDomainResponse {
  domainId: string | undefined;
  domainArn: string | undefined;
  domainStatus: DomainStatus | string | undefined;
}
export interface DeleteDomainRequest {
  domainId: string | undefined;
}
export interface DeleteDomainResponse {}
export interface GetCaseEventConfigurationRequest {
  domainId: string | undefined;
}
export interface CaseEventIncludedData {
  fields: FieldIdentifier[] | undefined;
}
export interface RelatedItemEventIncludedData {
  includeContent: boolean | undefined;
}
export interface EventIncludedData {
  caseData?: CaseEventIncludedData;
  relatedItemData?: RelatedItemEventIncludedData;
}
export interface EventBridgeConfiguration {
  enabled: boolean | undefined;
  includedData?: EventIncludedData;
}
export interface GetCaseEventConfigurationResponse {
  eventBridge: EventBridgeConfiguration | undefined;
}
export interface GetDomainRequest {
  domainId: string | undefined;
}
export interface GetDomainResponse {
  domainId: string | undefined;
  domainArn: string | undefined;
  name: string | undefined;
  createdTime: Date | undefined;
  domainStatus: DomainStatus | string | undefined;
  tags?: Record<string, string>;
}
export interface ListDomainsRequest {
  maxResults?: number;
  nextToken?: string;
}
export interface DomainSummary {
  domainId: string | undefined;
  domainArn: string | undefined;
  name: string | undefined;
}
export interface ListDomainsResponse {
  domains: DomainSummary[] | undefined;
  nextToken?: string;
}
export interface PutCaseEventConfigurationRequest {
  domainId: string | undefined;
  eventBridge: EventBridgeConfiguration | undefined;
}
export interface PutCaseEventConfigurationResponse {}
export interface BatchGetFieldRequest {
  domainId: string | undefined;
  fields: FieldIdentifier[] | undefined;
}
export interface FieldError {
  id: string | undefined;
  errorCode: string | undefined;
  message?: string;
}
export declare const FieldNamespace: {
  readonly CUSTOM: "Custom";
  readonly SYSTEM: "System";
};
export type FieldNamespace =
  (typeof FieldNamespace)[keyof typeof FieldNamespace];
export declare const FieldType: {
  readonly BOOLEAN: "Boolean";
  readonly DATE_TIME: "DateTime";
  readonly NUMBER: "Number";
  readonly SINGLE_SELECT: "SingleSelect";
  readonly TEXT: "Text";
  readonly URL: "Url";
};
export type FieldType = (typeof FieldType)[keyof typeof FieldType];
export interface GetFieldResponse {
  fieldId: string | undefined;
  name: string | undefined;
  fieldArn: string | undefined;
  description?: string;
  type: FieldType | string | undefined;
  namespace: FieldNamespace | string | undefined;
  tags?: Record<string, string>;
}
export interface BatchGetFieldResponse {
  fields: GetFieldResponse[] | undefined;
  errors: FieldError[] | undefined;
}
export interface FieldOption {
  name: string | undefined;
  value: string | undefined;
  active: boolean | undefined;
}
export interface BatchPutFieldOptionsRequest {
  domainId: string | undefined;
  fieldId: string | undefined;
  options: FieldOption[] | undefined;
}
export interface FieldOptionError {
  message: string | undefined;
  errorCode: string | undefined;
  value: string | undefined;
}
export interface BatchPutFieldOptionsResponse {
  errors?: FieldOptionError[];
}
export interface CreateFieldRequest {
  domainId: string | undefined;
  name: string | undefined;
  type: FieldType | string | undefined;
  description?: string;
}
export interface CreateFieldResponse {
  fieldId: string | undefined;
  fieldArn: string | undefined;
}
export interface ListFieldOptionsRequest {
  domainId: string | undefined;
  fieldId: string | undefined;
  maxResults?: number;
  nextToken?: string;
  values?: string[];
}
export interface ListFieldOptionsResponse {
  options: FieldOption[] | undefined;
  nextToken?: string;
}
export interface ListFieldsRequest {
  domainId: string | undefined;
  maxResults?: number;
  nextToken?: string;
}
export interface FieldSummary {
  fieldId: string | undefined;
  fieldArn: string | undefined;
  name: string | undefined;
  type: FieldType | string | undefined;
  namespace: FieldNamespace | string | undefined;
}
export interface ListFieldsResponse {
  fields: FieldSummary[] | undefined;
  nextToken?: string;
}
export interface UpdateFieldRequest {
  domainId: string | undefined;
  fieldId: string | undefined;
  name?: string;
  description?: string;
}
export interface UpdateFieldResponse {}
export interface FieldItem {
  id: string | undefined;
}
export interface FieldGroup {
  name?: string;
  fields: FieldItem[] | undefined;
}
export type Section = Section.FieldGroupMember | Section.$UnknownMember;
export declare namespace Section {
  interface FieldGroupMember {
    fieldGroup: FieldGroup;
    $unknown?: never;
  }
  interface $UnknownMember {
    fieldGroup?: never;
    $unknown: [string, any];
  }
  interface Visitor<T> {
    fieldGroup: (value: FieldGroup) => T;
    _: (name: string, value: any) => T;
  }
  const visit: <T>(value: Section, visitor: Visitor<T>) => T;
}
export interface LayoutSections {
  sections?: Section[];
}
export interface BasicLayout {
  topPanel?: LayoutSections;
  moreInfo?: LayoutSections;
}
export type LayoutContent =
  | LayoutContent.BasicMember
  | LayoutContent.$UnknownMember;
export declare namespace LayoutContent {
  interface BasicMember {
    basic: BasicLayout;
    $unknown?: never;
  }
  interface $UnknownMember {
    basic?: never;
    $unknown: [string, any];
  }
  interface Visitor<T> {
    basic: (value: BasicLayout) => T;
    _: (name: string, value: any) => T;
  }
  const visit: <T>(value: LayoutContent, visitor: Visitor<T>) => T;
}
export interface CreateLayoutRequest {
  domainId: string | undefined;
  name: string | undefined;
  content: LayoutContent | undefined;
}
export interface CreateLayoutResponse {
  layoutId: string | undefined;
  layoutArn: string | undefined;
}
export interface GetLayoutRequest {
  domainId: string | undefined;
  layoutId: string | undefined;
}
export interface GetLayoutResponse {
  layoutId: string | undefined;
  layoutArn: string | undefined;
  name: string | undefined;
  content: LayoutContent | undefined;
  tags?: Record<string, string>;
}
export interface ListLayoutsRequest {
  domainId: string | undefined;
  maxResults?: number;
  nextToken?: string;
}
export interface LayoutSummary {
  layoutId: string | undefined;
  layoutArn: string | undefined;
  name: string | undefined;
}
export interface ListLayoutsResponse {
  layouts: LayoutSummary[] | undefined;
  nextToken?: string;
}
export interface UpdateLayoutRequest {
  domainId: string | undefined;
  layoutId: string | undefined;
  name?: string;
  content?: LayoutContent;
}
export interface UpdateLayoutResponse {}
export interface ListTagsForResourceRequest {
  arn: string | undefined;
}
export interface ListTagsForResourceResponse {
  tags?: Record<string, string>;
}
export interface TagResourceRequest {
  arn: string | undefined;
  tags: Record<string, string> | undefined;
}
export interface LayoutConfiguration {
  defaultLayout?: string;
}
export interface RequiredField {
  fieldId: string | undefined;
}
export declare const TemplateStatus: {
  readonly ACTIVE: "Active";
  readonly INACTIVE: "Inactive";
};
export type TemplateStatus =
  (typeof TemplateStatus)[keyof typeof TemplateStatus];
export interface CreateTemplateRequest {
  domainId: string | undefined;
  name: string | undefined;
  description?: string;
  layoutConfiguration?: LayoutConfiguration;
  requiredFields?: RequiredField[];
  status?: TemplateStatus | string;
}
export interface CreateTemplateResponse {
  templateId: string | undefined;
  templateArn: string | undefined;
}
export interface GetTemplateRequest {
  domainId: string | undefined;
  templateId: string | undefined;
}
export interface GetTemplateResponse {
  templateId: string | undefined;
  templateArn: string | undefined;
  name: string | undefined;
  description?: string;
  layoutConfiguration?: LayoutConfiguration;
  requiredFields?: RequiredField[];
  tags?: Record<string, string>;
  status: TemplateStatus | string | undefined;
}
export interface ListTemplatesRequest {
  domainId: string | undefined;
  maxResults?: number;
  nextToken?: string;
  status?: (TemplateStatus | string)[];
}
export interface TemplateSummary {
  templateId: string | undefined;
  templateArn: string | undefined;
  name: string | undefined;
  status: TemplateStatus | string | undefined;
}
export interface ListTemplatesResponse {
  templates: TemplateSummary[] | undefined;
  nextToken?: string;
}
export interface UpdateTemplateRequest {
  domainId: string | undefined;
  templateId: string | undefined;
  name?: string;
  description?: string;
  layoutConfiguration?: LayoutConfiguration;
  requiredFields?: RequiredField[];
  status?: TemplateStatus | string;
}
export interface UpdateTemplateResponse {}
export interface UntagResourceRequest {
  arn: string | undefined;
  tagKeys: string[] | undefined;
}
export type CaseFilter =
  | CaseFilter.AndAllMember
  | CaseFilter.FieldMember
  | CaseFilter.NotMember
  | CaseFilter.$UnknownMember;
export declare namespace CaseFilter {
  interface FieldMember {
    field: FieldFilter;
    not?: never;
    andAll?: never;
    $unknown?: never;
  }
  interface NotMember {
    field?: never;
    not: CaseFilter;
    andAll?: never;
    $unknown?: never;
  }
  interface AndAllMember {
    field?: never;
    not?: never;
    andAll: CaseFilter[];
    $unknown?: never;
  }
  interface $UnknownMember {
    field?: never;
    not?: never;
    andAll?: never;
    $unknown: [string, any];
  }
  interface Visitor<T> {
    field: (value: FieldFilter) => T;
    not: (value: CaseFilter) => T;
    andAll: (value: CaseFilter[]) => T;
    _: (name: string, value: any) => T;
  }
  const visit: <T>(value: CaseFilter, visitor: Visitor<T>) => T;
}
export interface SearchCasesRequest {
  domainId: string | undefined;
  maxResults?: number;
  nextToken?: string;
  searchTerm?: string;
  filter?: CaseFilter;
  sorts?: Sort[];
  fields?: FieldIdentifier[];
}
